@@ -4,7 +4,7 @@ from ramda.curry import curry
 @curry
 def has(name, o):
     """Returns whether or not an object has an own property with the specified name"""
-    if hasattr(o, name):
+    if hasattr(o, str(name)):
         return True
 
     try:
