@@ -4,4 +4,7 @@ from toolz import curry
 @curry
 def mean(xs):
     """Returns the mean of the given list of numbers"""
-    return sum(xs) / len(xs)
+    try:
+        return sum(xs) / len(xs)
+    except ZeroDivisionError:
+        return None
