@@ -1,5 +1,6 @@
 from toolz import curry
 from ramda.equals import equals
+from ramda.prop import prop
 
 
 @curry
@@ -7,7 +8,4 @@ def prop_eq(property, value, object):
     """Returns true if the specified object property is equal, in
     R.equals terms, to the given value; false otherwise.
     You can test multiple properties with R.where"""
-    try:
-        return equals(object[property], value)
-    except KeyError:
-        return False
+    return equals(prop(property, object), value)
